@@ -19,9 +19,10 @@
 #'  one or more remote URLs are registered for the hash, downloads 
 #'  from these will be attempted in order from most recent first.
 #' @seealso query query_local query_remote
-#' @examples
+#' @examplesIf interactive()
 #' \dontshow{ ## Real users won't use a temporary dir
 #' Sys.setenv("CONTENTID_REGISTRIES" = tempdir())
+#' Sys.setenv("CONTENTID_HOME" = tempdir())
 #' }
 #' # ensure some content in local storage for testing purposes:
 #' vostok_co2 <- system.file("extdata", "vostok.icecore.co2",
@@ -36,6 +37,7 @@
 #' }
 #' \dontshow{ ## Real users won't use a temporary dir
 #' Sys.unsetenv("CONTENTID_REGISTRIES")
+#' Sys.unsetenv("CONTENTID_HOME")
 #' }
 #' 
 #' 
@@ -47,7 +49,7 @@ resolve <- function(id,
                     dir = content_dir(),
                     ...) {
   
-  df <- query_sources(id, registries, cols=c("identifier", "source", "date"), 
+  df <- sources(id, registries, cols=c("identifier", "source", "date"), 
                       all = FALSE, ...)
   
   if(is.null(df) || nrow(df) == 0){
